@@ -280,7 +280,8 @@ class EFAwsResolver(object):
     Args:
       lookup - the friendly name of the VPC whose subnets we want
     Returns:
-      A comma-separated list of all subnets in use in the named VPC or default/None if no match found
+      A comma-separated list of all public subnets in use in the named VPC or default/None if no match found.
+      This will not return the list of private subnets.
     """
     vpc_id = self.ec2_vpc_vpc_id(lookup)
     if vpc_id is None:
@@ -289,9 +290,18 @@ class EFAwsResolver(object):
       'Name': 'vpc-id',
       'Values': [vpc_id]
     }])
-    if len(subnets["Subnets"]) > 0:
+    public_subnets = []
+    for subnet in subnets['Subnets']:
+      routes = EFAwsResolver.__CLIENTS["ec2"].describe_route_tables(Filters=[
+        {'Name': 'association.subnet-id',
+         'Values': [subnet["SubnetId"]]}])['RouteTables'][0]['Routes']
+      is_public = any(route['GatewayId'].startswith('igw-') for route in routes if 'GatewayId' in route)
+      if is_public:
+        public_subnets.append(subnet)
+
+    if len(public_subnets) > 0:
       # Strip the metadata section (subnets["Subnets"])
-      subnet_list = [s["SubnetId"] for s in subnets["Subnets"]]
+      subnet_list = [s["SubnetId"] for s in public_subnets]
       # Add internal ", " only. This is called literally from: "{{aws...}}" - reuses the outer quotes
       return "\", \"".join(subnet_list)
     else:
@@ -992,6 +1002,27 @@ class EFAwsResolver(object):
     else:
       return default
 
+  def secrets_manager_secret_arn(self, lookup, default=None):
+    """
+    Args:
+      lookup: the name of the secret
+      default: the optional value to return if lookup failed; returns None if not set
+    Returns:
+      The arn of the first secret found with a name matching 'lookup' or default/None if no match found
+    """
+    secrets = EFAwsResolver.__CLIENTS["secretsmanager"].list_secrets(
+      Filters=[
+        {
+          'Key': 'name',
+          'Values': [lookup]
+        },
+      ]
+    )
+    if len(secrets.get('SecretList')) > 0:
+      return secrets['SecretList'][0]['ARN']
+    else:
+      return default
+
   def ec2_transit_gateway_id(self, lookup, default=None):
     """
     Args:
@@ -1127,6 +1158,8 @@ class EFAwsResolver(object):
       return self.route53_private_hosted_zone_id(*kv[1:])
     elif kv[0] == "route53:public-hosted-zone-id":
       return self.route53_public_hosted_zone_id(*kv[1:])
+    elif kv[0] == "secretsmanager:secret-arn":
+      return self.secrets_manager_secret_arn(*kv[1:])
     elif kv[0] == "waf:ip-set-id":
       return self.waf_ip_set_id(*kv[1:])
     elif kv[0] == "waf:rule-id":
